@@ -1,5 +1,5 @@
 /*
-** Copyright 2017-2019,2020 Thomas E. Dickey
+** Copyright 2017-2020,2024 Thomas E. Dickey
 ** Copyright 1997-2012,2017 Free Software Foundation, Inc.
 **
 ** This file is part of TACK.
@@ -21,7 +21,7 @@
 
 #include <tack.h>
 
-MODULE_ID("$Id: charset.c,v 1.28 2020/02/02 14:47:18 tom Exp $")
+MODULE_ID("$Id: charset.c,v 1.29 2024/04/30 19:58:07 tom Exp $")
 
 /*
 	Menu definitions for alternate character set and SGR tests.
@@ -126,7 +126,7 @@ charset_status(
 {
     int i, max;
     char *s;
-    static char m[] = "*** status line *** 123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.";
+    static const char m[] = "*** status line *** 123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.";
 
     if (has_status_line != 1) {
 	return;
@@ -160,7 +160,7 @@ charset_eslok(
 {
     int i, max;
     char *s;
-    static char m[] = "*** status line *** 123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.";
+    static const char m[] = "*** status line *** 123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.123456789.";
 
     if (has_status_line != 1) {
 	return;
