@@ -1,12 +1,12 @@
 /*
-** Copyright (C) 1991, 1997-2011,2017 Free Software Foundation, Inc.
+** Copyright 2017,2020,2024 Thomas E. Dickey
+** Copyright 1997-2011,2017 Free Software Foundation, Inc.
 ** 
 ** This file is part of TACK.
 ** 
 ** TACK is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2, or (at your option)
-** any later version.
+** the Free Software Foundation, version 2.
 ** 
 ** TACK is distributed in the hope that it will be useful,
 ** but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -21,7 +21,7 @@
 
 #include <tack.h>
 
-MODULE_ID("$Id: crum.c,v 1.11 2017/07/23 16:08:17 tom Exp $")
+MODULE_ID("$Id: crum.c,v 1.16 2024/04/30 19:57:08 tom Exp $")
 
 /*
  * Test cursor movement.
@@ -33,7 +33,8 @@ static void crum_ll(TestList * t, int *state, int *ch);
 static void crum_move(TestList * t, int *state, int *ch);
 static void crum_os(TestList * t, int *state, int *ch);
 
-static char crum_text[5][80];
+#define CRUM_SIZE 80
+static char crum_text[5][CRUM_SIZE];
 
 TestList crum_test_list[] =
 {
@@ -187,7 +188,7 @@ move_to(
 static void
 display_it(
 	      int sel,
-	      char *txt)
+	      const char *txt)
 {
     int i, done_line;
 
@@ -246,9 +247,9 @@ crum_clear(
 	      int *state,
 	      int *ch)
 {
-    int i;
-
     if (clear_screen) {
+	int i;
+
 	for (i = lines; i > 1; i--) {
 	    putln("garbage");
 	}
@@ -378,7 +379,7 @@ crum_move(
 	put_str("  Done. ");
     } else {
 	can_test(buf, FLAG_TESTED);
-	strcpy(crum_text[n], &buf[2]);
+	sprintf(crum_text[n], "%.*s", CRUM_SIZE - 1, &buf[2]);
 	crum_text[n][strlen(buf) - 3] = '\0';
 
 	display_it(1 << n, buf);
@@ -400,9 +401,9 @@ crum_os(
 	   int *state,
 	   int *ch)
 {
-    int i;
-
     if (cursor_address && over_strike) {
+	int i;
+
 	put_clear();
 	for (i = 0; i < columns - 2; i++) {
 	    tc_putch('|');
